@@ -26,11 +26,14 @@ class SapHanaConnector(ToucanConnector):
 
     port: int = Field(..., description='The listening port of your database server')
     user: str = Field(..., description='Your login username')
-    password: SecretStr = Field(..., description='Your login password')
+    password: SecretStr = Field('', description='Your login password')
 
     def _retrieve_data(self, data_source):
         connection = pyhdb.connect(
-            self.host, self.port, self.user, self.password.get_secret_value()
+            self.host,
+            self.port,
+            self.user,
+            self.password.get_secret_value() if self.password else SecretStr('').get_secret_value(),
         )
 
         df = pandas_read_sql(data_source.query, con=connection)
